@@ -6,7 +6,7 @@ use opengl_graphics::{GlGraphics, OpenGL};
 use piston::event_loop::{EventSettings, Events};
 use piston::input::{RenderEvent, UpdateEvent};
 use piston::window::WindowSettings;
-use piston::{Button, EventLoop, IdleEvent, Key, PressEvent, ReleaseEvent};
+use piston::{Button, EventLoop, Key, PressEvent, ReleaseEvent};
 
 const FPS: u64 = 60;
 const NUM_PLAYERS: usize = 2;
@@ -79,11 +79,6 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
             }
         }
 
-        // idle
-        if let Some(_args) = e.idle_args() {
-            // poll remote endpoints, but not in the synctest
-        }
-
         // update key state
         if let Some(Button::Keyboard(key)) = e.press_args() {
             match key {
