@@ -5,7 +5,6 @@
 
 //#![warn(clippy::all, clippy::pedantic, clippy::nursery, clippy::cargo)]
 
-use std::fmt::Display;
 use std::net::SocketAddr;
 
 pub use error::GGRSError;
@@ -118,16 +117,6 @@ pub enum GGRSRequest {
     AdvanceFrame { inputs: Vec<GameInput> },
 }
 
-impl Display for GGRSRequest {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self {
-            GGRSRequest::SaveGameState { .. } => write!(f, "SaveGameState"),
-            GGRSRequest::LoadGameState { .. } => write!(f, "LoadGameState"),
-            &GGRSRequest::AdvanceFrame { .. } => write!(f, "AdvanceFrame"),
-        }
-    }
-}
-
 /// Used to create a new `SyncTestSession`. During a sync test, GGRS will simulate a rollback every frame and resimulate the last n states, where n is the given `check_distance`.
 /// During a `SyncTestSession`, GGRS will simulate a rollback every frame and resimulate the last n states, where n is the given check distance.
 /// The resimulated checksums will be compared with the original checksums and report if there was a mismatch.
@@ -189,7 +178,6 @@ pub fn start_synctest_session(
 /// # Errors
 /// - Will return a `InvalidRequest` if the number of players is higher than the allowed maximum (see `MAX_PLAYERS`).
 /// - Will return a `InvalidRequest` if `input_size` is higher than the allowed maximum (see  `MAX_INPUT_BYTES`).
-/// - Will return a `InvalidRequest` if the `check_distance is` higher than the allowed maximum (see `MAX_PREDICTION_FRAMES`).
 /// - Will return `SocketCreationFailed` if the UPD socket could not be created.
 pub fn start_p2p_session(
     num_players: u32,
@@ -225,7 +213,6 @@ pub fn start_p2p_session(
 /// # Errors
 /// - Will return a `InvalidRequest` if the number of players is higher than the allowed maximum (see `MAX_PLAYERS`).
 /// - Will return a `InvalidRequest` if `input_size` is higher than the allowed maximum (see  `MAX_INPUT_BYTES`).
-/// - Will return a `InvalidRequest` if the `check_distance is` higher than the allowed maximum (see `MAX_PREDICTION_FRAMES`).
 /// - Will return `SocketCreationFailed` if the UPD socket could not be created.
 pub fn start_p2p_spectator_session(
     num_players: u32,
